Skip to contents

Returns the temporary session-scoped cache directory used by deconvolution functions such as deconvolute() and the internal grid_deconvolute_spectrum() helper.

Usage

decon_cachedir()

Value

Path to the shared temporary cache directory for deconvolution.

Author

2026 Tobias Schmidt: initial version.

Examples

decon_cachedir()
#> [1] "/tmp/RtmpTeNkY0/metabodecon/cache/deconvs"