Learn R Programming

metabodecon (version 1.6.2)

metabodecon_file: Return Path to File or Directory in metabodecon Package

Description

Recursively searches for files or directories within the 'metabodecon' package that match the given name.

Usage

metabodecon_file(name = "sim_01")

Value

The file or directory path.

Arguments

name

The name to search for.

Author

2024-2025 Tobias Schmidt: initial version.

Examples

Run this code
# Unambiguous paths
metabodecon_file("urine_1")
metabodecon_file("urine_1.dx")
metabodecon_file("sim/sim_01")

# Ambiguous paths (i.e. multiple matches)
metabodecon_file("sim")
metabodecon_file("urine")

# Non-existing paths (i.e. a character vector of length zero gets returned)
metabodecon_file("asdfasdf")

Run the code above in your browser using DataLab