Learn R Programming

metabodecon (version 1.6.2)

transp: Make transparent

Description

Make a color transparent by adding an alpha channel.

Usage

transp(col = "violet", alpha = 0.08)

Value

A character string representing the color with an alpha channel.

Arguments

col

Character string specifying the color to make transparent.

alpha

Numeric value between 0 and 1 specifying the transparency level.

Author

2024-2025 Tobias Schmidt: initial version.

Examples

Run this code
transp("violet", 0.08)
transp("black", 0.5)

Run the code above in your browser using DataLab