Converts positions/widths from unit A to unit B. If the direction of units A
and B is reversed, the width's sign will be reversed as well. To keep widths
strictly positive, wrap the result with abs().
Usage
convert_pos(xa, ya, yb)
convert_width(xa, ya, yb)
Value
A numeric vector of values converted from unit A to unit B.
Arguments
xa
A numeric vector specifying widths/positions in unit A.
ya, yb
A numeric vector specifying the positions of at least two points in unit A /
unit B.