- x
A spectrum or spectra object as described in Metabodecon Classes.
- nfit
Integer. Number of iterations for approximating the parameters
for the Lorentz curves. See 'Details'.
- smopts
Numeric vector with two entries: the number of smoothing
iterations and the number of data points to use for smoothing (must be odd).
See 'Details'.
- delta
Threshold for peak filtering. Higher values result in more peaks
being filtered out. A peak is filtered if its score is below \(\mu +
\sigma \cdot \delta\), where \(\mu\) is the average
peak score in the signal-free region (SFR), and \(\sigma\) is the
standard deviation of peak scores in the SFR. See 'Details'.
- sfr
Numeric vector with two entries: the ppm positions for the left
and right border of the signal-free region of the spectrum. See 'Details'.
- wshw
Half-width of the water artifact in ppm. See 'Details'.
- ask
Logical. Whether to ask for user input during the deconvolution
process. If FALSE, the provided default values will be used.
- force
If FALSE, the function stops with an error message if no peaks
are found in the signal free region (SFR), as these peaks are required as a
reference for peak filtering. If TRUE, the function instead proceeds without
peak filtering, potentially increasing runtime and memory usage
significantly.
- verbose
Logical. Whether to print log messages during the
deconvolution process.
- nworkers
Number of workers to use for parallel processing. If
"auto", the number of workers will be determined automatically. If a number
greater than 1, it will be limited to the number of spectra.
- use_rust
Logical. Whether to use the Rust backend for deconvolution.
Requires the mdrb package. If TRUE and
mdrb is missing, an error is thrown. If FALSE, the R implementation is used.
If NULL, the Rust backend is used if available, otherwise the R implementation
is used.