if (interactive()) {
# Example requires an interactive R session, because in case of missing
# dependencies the user will be asked for confirmation to install them.
decons <- deconvolute(sim[1:2], sfr = c(3.55, 3.35))
aligns <- align(decons)
si_mat <- get_si_mat(aligns) # 2048 x 2 matrix (2048 datapoints, 2 spectra)
}
Run the code above in your browser using DataLab