Returns the first and last n rows of a matrix or data frame. If the input
has fewer than 2*n rows, overlapping rows are returned only once.
Returns the first and last n rows of a matrix or data frame. If the input
has fewer than 2*n rows, overlapping rows are returned only once.