powered by
Make a color transparent by adding an alpha channel.
transp(col = "violet", alpha = 0.08)
A character string representing the color with an alpha channel.
Character string specifying the color to make transparent.
Numeric value between 0 and 1 specifying the transparency level.
2024-2025 Tobias Schmidt: initial version.
transp("violet", 0.08) transp("black", 0.5)
Run the code above in your browser using DataLab